@@ -12,9 +12,9 @@ import (
 	exutil "github.com/openshift/origin/test/extended/util"
 )
 
-var _ = g.Describe("etcd", func() {
+var _ = g.Describe("[sig-etcd] etcd", func() {
 	defer g.GinkgoRecover()
-	oc := exutil.NewCLI("etcd-leader-change", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("etcd-leader-change").AsAdmin()
 	g.It("leader changes are not excessive", func() {
 		prometheus, err := client.NewE2EPrometheusRouterClient(oc)
 		o.Expect(err).ToNot(o.HaveOccurred())
