@@ -58,7 +58,7 @@ func (t *AvailableTest) Setup(f *framework.Framework) {
 	client, err := routeclientset.NewForConfig(config)
 	framework.ExpectNoError(err)
 	for i, frontend := range t.frontends {
-		route, err := client.RouteV1().Routes(frontend.Namespace).Get(frontend.Name, metav1.GetOptions{})
+		route, err := client.RouteV1().Routes(frontend.Namespace).Get(context.Background(), frontend.Name, metav1.GetOptions{})
 		framework.ExpectNoError(err)
 		for _, ingress := range route.Status.Ingress {
 			if len(ingress.Host) > 0 {
@@ -132,7 +132,7 @@ func startEndpointMonitoring(ctx context.Context, m *monitor.Monitor, frontend F
 	}
 	m.AddSampler(
 		monitor.StartSampling(ctx, m, time.Second, func(previous bool) (condition *monitor.Condition, next bool) {
-			data, err := continuousClient.Get().AbsPath(frontend.Path).DoRaw()
+			data, err := continuousClient.Get().AbsPath(frontend.Path).DoRaw(ctx)
 			if err == nil && !bytes.Contains(data, []byte(frontend.Expect)) {
 				err = fmt.Errorf("route returned success but did not contain the correct body contents: %q", string(data))
 			}
@@ -185,7 +185,7 @@ func startEndpointMonitoring(ctx context.Context, m *monitor.Monitor, frontend F
 	}
 	m.AddSampler(
 		monitor.StartSampling(ctx, m, time.Second, func(previous bool) (condition *monitor.Condition, next bool) {
-			data, err := client.Get().AbsPath(frontend.Path).DoRaw()
+			data, err := client.Get().AbsPath(frontend.Path).DoRaw(ctx)
 			switch {
 			case err == nil && len(frontend.Expect) != 0 && !bytes.Contains(data, []byte(frontend.Expect)):
 				err = fmt.Errorf("route returned success but did not contain the correct body contents: %q", string(data))
